@@ -51,7 +51,9 @@ c
       integer icon,  loopc
       
       integer KKMAT
-
+c///////////
+      integer i
+c/////////
 
       integer  NEVENT, ICASCA
       COMMON /DTEVNO/ NEVENT,ICASCA
@@ -175,6 +177,19 @@ c               endif
             endif
          endif
       endif
+c/////////////////////
+      do i = 1, ntp
+         if(a(i).code .eq. kphoton .and.  a(i).charge .ne.  0) then
+            write(0,*)
+     *       'dpmerr  photon charge=' ,a(i).charge, ' subc=',
+     *       a(i).subcode, ' E=',a(i).fm.p(4)
+            write(0,*)
+     *      'dpmerr dodpm=',dodpm,' ntp=', ntp, ' pj=', pj.code,
+     *       ' pj.charge=', pj.charge, ' ia=',ia, ' iz=', iz
+         endif
+      enddo
+c/////////////////
+
       end
       subroutine cpdpmjetinp
       implicit none
