@@ -41,7 +41,9 @@ c        *****************
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
 
-         real*8 beg, den, cvh2den 
+         real*8 beg, den, cvh2den
+         real*8 theta, sint, cost, sn, cs
+         record /coord/dc1, w
          record /track/ aTrack
 
 c           get brem gamma energy
@@ -63,12 +65,30 @@ c
 c         see           !! note above
          Pwork(Nproduced+2) = aTrack.p
 
-         aTrack.p.fm.p(4) = beg
-         call cmkptc(kphoton,  kcasg, 0,  aTrack.p)
-         call ce2p(aTrack)
-         Pwork(Nproduced+1) = aTrack.p
 
-         Nproduced = Nproduced + 2
+          aTrack.p.fm.p(4) = beg
+          call cmkptc(kphoton,  kcasg, 0,  aTrack.p)
+c           brems angle at low energy
+         if(  TrackBefMove.p.fm.p(4)  .lt. 10. ) then
+             call cBremAng( TrackBefMove.p.fm.p(4), TrackBefMove.p.mass, beg,
+     *           TargetAtomicN, theta)
+             if(theta .lt. 0.03d0) then
+                sint = theta
+                cost = 1.- theta**2 / 2
+             else
+                sint = sin(theta)
+                cost = cos(theta)
+             endif
+             call kcossn(cs,sn)
+             w.x = cs*sint
+             w.y = sn*sint
+             w.z = cost
+             call ctransVectZ(MovedTrack.vec.w, w, dc1)
+             call csetDirCos(dc1, aTrack)
+          endif
+          call ce2p(aTrack)
+          Pwork(Nproduced+1) = aTrack.p
+          Nproduced = Nproduced + 2
          end
 c      *****************
        subroutine cknockon(cg)
